aboutsummaryrefslogtreecommitdiffstats
path: root/widgets/misc/e-cell-date-edit.h
diff options
context:
space:
mode:
authorDamon Chaplin <damon@ximian.com>2001-03-05 07:55:37 +0800
committerDamon Chaplin <damon@src.gnome.org>2001-03-05 07:55:37 +0800
commit7b7acde405898803001e1614e6ffd15df7682391 (patch)
tree951c9ee6634030e9e0a139103370092ad39c01dc /widgets/misc/e-cell-date-edit.h
parent3874e64dfdf4ec308a0b81644d8420a546508454 (diff)
downloadgsoc2013-evolution-7b7acde405898803001e1614e6ffd15df7682391.tar
gsoc2013-evolution-7b7acde405898803001e1614e6ffd15df7682391.tar.gz
gsoc2013-evolution-7b7acde405898803001e1614e6ffd15df7682391.tar.bz2
gsoc2013-evolution-7b7acde405898803001e1614e6ffd15df7682391.tar.lz
gsoc2013-evolution-7b7acde405898803001e1614e6ffd15df7682391.tar.xz
gsoc2013-evolution-7b7acde405898803001e1614e6ffd15df7682391.tar.zst
gsoc2013-evolution-7b7acde405898803001e1614e6ffd15df7682391.zip
pretty much working now.
2001-03-04 Damon Chaplin <damon@ximian.com> * e-cell-date-edit.c: pretty much working now. svn path=/trunk/; revision=8548
Diffstat (limited to 'widgets/misc/e-cell-date-edit.h')
-rw-r--r--widgets/misc/e-cell-date-edit.h22
1 files changed, 21 insertions, 1 deletions
diff --git a/widgets/misc/e-cell-date-edit.h b/widgets/misc/e-cell-date-edit.h
index a852b95361..f3f8beb02b 100644
--- a/widgets/misc/e-cell-date-edit.h
+++ b/widgets/misc/e-cell-date-edit.h
@@ -43,13 +43,27 @@ typedef struct {
ECellPopup parent;
GtkWidget *popup_window;
+ GtkWidget *calendar;
+ GtkWidget *time_entry;
GtkWidget *time_list;
- /* This is the range of hours we show in the time popup. */
+ GtkWidget *now_button;
+ GtkWidget *today_button;
+ GtkWidget *none_button;
+
+ /* This is the range of hours we show in the time list. */
gint lower_hour;
gint upper_hour;
+ /* TRUE if we use 24-hour format for the time list and entry. */
gboolean use_24_hour_format;
+
+ /* This is TRUE if we need to rebuild the list of times. */
+ gboolean need_time_list_rebuild;
+
+ /* The freeze count for rebuilding the time list. We only rebuild when
+ this is 0. */
+ gint freeze_count;
} ECellDateEdit;
typedef struct {
@@ -61,4 +75,10 @@ GtkType e_cell_date_edit_get_type (void);
ECell *e_cell_date_edit_new (void);
+/* These freeze and thaw the rebuilding of the time list. They are useful when
+ setting several properties which result in rebuilds of the list, e.g. the
+ lower_hour, upper_hour and use_24_hour_format properties. */
+void e_cell_date_edit_freeze (ECellDateEdit *ecde);
+void e_cell_date_edit_thaw (ECellDateEdit *ecde);
+
#endif /* _E_CELL_DATE_EDIT_H_ */